@@ -76,7 +76,11 @@ pal_aaas <- function(palette = c("default"), alpha = 1) {
 #'   scale_fill_aaas()
 scale_color_aaas <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", palette = pal_aaas(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_aaas(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "aaas", palette = pal_aaas(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_aaas
@@ -88,5 +92,9 @@ scale_colour_aaas <- scale_color_aaas
 #' @rdname scale_aaas
 scale_fill_aaas <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", palette = pal_aaas(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_aaas(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "aaas", palette = pal_aaas(palette, alpha), ...)
+  }
 }
